@@ -7,6 +7,7 @@ Can be used/invoked as a module, why? because print is a valid debug tool!
 """
 # Import the typing library so variables can be type cast
 from typing import List, Optional, Tuple
+from typing_extensions import TypeAlias
 
 # Import the sys to get any argv used
 import sys
@@ -21,14 +22,14 @@ import random
 from ewccommons import str_lower_list
 from ewccommons.errors import not_what_i_wanted
 
-_Die_Faces_ = List[int]
+_Die_Faces_: TypeAlias = List[int]
 """Type Alias Definition
 
 A die face values list variable structure.
 """
 
 # Define the dice cup list variable type
-_Dice_Cup_ = List[_Die_Faces_]
+_Dice_Cup_: TypeAlias = List[_Die_Faces_]
 """Type Alias Definition
 
 A list collection of die face values list variable structure.
@@ -254,7 +255,7 @@ class Dice:
         return self.__rolled >= o
 
 
-_Dice_ = List[Dice]
+_Dice_: TypeAlias = List[Dice]
 """Type Alias Definition
 
 A list collection of Dice instances variable structure.
